@@ -1,9 +1,11 @@
 import click
 
 from mobt import echo
+from mobt.GitCli.BranchName import BranchName
 
 
 @click.command()
+@click.argument('branch_name', required=False)
 @click.option(
     '--message',
     '-m',
@@ -17,10 +19,12 @@ from mobt import echo
          'will be aborted.',
 )
 @click.pass_context
-def done(ctx, message: str = None, do_not_try_to_rebase: bool = False) -> None:
+def done(ctx, branch_name: BranchName = None, message: str = None, do_not_try_to_rebase: bool = False) -> None:
     """
         End the current mob session.
 
+        The BRANCH_NAME is optional. If not passed, it will use the current branch of your repository.
+
         It will remove the mob session file, squash all the commits and push all the changes to the remote.
         All git hooks will be executed for this final commit.
 
@@ -30,6 +34,6 @@ def done(ctx, message: str = None, do_not_try_to_rebase: bool = False) -> None:
     """
     from mobt.di import di
     from mobt.MobApp.EndMob import EndMob
-    di.get(EndMob).end(message=message, do_not_try_to_rebase=do_not_try_to_rebase)
+    di.get(EndMob).end(branch_name=branch_name, message=message, do_not_try_to_rebase=do_not_try_to_rebase)
 
     echo(f'Done!', fg='green')
