@@ -3,4 +3,4 @@ import logging
 
 class Filter(logging.Filter):
     def filter(self, record: logging.LogRecord) -> bool:
-        return True
+        return record.name != 'git.cmd'
