@@ -1,8 +1,6 @@
-import logging
 from dataclasses import dataclass
 from typing import Optional
 
-from mobt.Logging.color_by_log_level import color_by_log_level_int
 from mobt.PopenObserver.PopenListener import PopenListener
 
 
@@ -26,25 +24,34 @@ class GitPopenListener(PopenListener):
         msg = " ".join(command)
         from mobt.MobApp import mob_app_logger
 
-        if self._is_git_command(command) and not self._is_git_version_command(command):
+        whole_output = ((stdout or "") + (stderr or "")).strip()
+        if self._is_git_command(command):
             from mobt import echo
 
-            echo(msg, fg=color_by_log_level_int(logging.INFO))
-            whole_output = stdout + stderr
+            if self._is_safe_command(command):
+                mob_app_logger().debug(msg)
+            else:
+                mob_app_logger().info(msg)
 
             if self._is_git_push_command(command):
-                pull_request_url = self._get_pul_requet_url(whole_output)
+                pull_request_url = self._get_pul_request_url(whole_output)
                 if pull_request_url:
-                    echo(f'To {pull_request_url.action} {pull_request_url.term}, visit:\n   {pull_request_url.url}',
-                         fg='bright_blue')
-
-            mob_app_logger().debug(whole_output)
+                    echo(
+                        f'To {pull_request_url.action} {pull_request_url.term}, visit:\n   {pull_request_url.url}',
+                        fg='bright_blue'
+                    )
         else:
             mob_app_logger().debug(msg)
-            whole_output = stdout + stderr
-            mob_app_logger().debug(whole_output)
 
-    def _get_pul_requet_url(self, text: str) -> Optional[PullRequestUrl]:
+        if whole_output:
+            formatted_output = whole_output.replace("\n", "\n   > ")
+            mob_app_logger().debug(f'   > {formatted_output}')
+
+    def _is_safe_command(self, command: list) -> bool:
+        safe_sub_commands = ['diff', 'fetch', 'version', 'merge-base']
+        return any(self._is_git_command(command, sub_command) for sub_command in safe_sub_commands)
+
+    def _get_pul_request_url(self, text: str) -> Optional[PullRequestUrl]:
         if not text or 'https://' not in text:
             return None
 
@@ -66,11 +73,8 @@ class GitPopenListener(PopenListener):
 
         return None
 
-    def _is_git_command(self, command: list) -> bool:
-        return command and command[0] == 'git'
-
-    def _is_git_version_command(self, command: list) -> bool:
-        return command and command[0] == 'git' and command[1] == 'version'
+    def _is_git_command(self, command: list, sub_command: str = None) -> bool:
+        return command and command[0] == 'git' and (not sub_command or command[1] == sub_command)
 
     def _is_git_push_command(self, command: list) -> bool:
-        return command and command[0] == 'git' and command[1] == 'push'
+        return self._is_git_command(command, 'push')
